@@ -1,20 +1,25 @@
-# Copyrights 2006-2017 by [Mark Overmeer].
+# Copyrights 2006-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution XML-Compile.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
+package XML::Compile::Schema::BuiltInFacets;
+use vars '$VERSION';
+$VERSION = '1.60';
+
+use base 'Exporter';
+
 use warnings;
 use strict;
 no warnings 'recursion';
 
-package XML::Compile::Schema::BuiltInFacets;
-use vars '$VERSION';
-$VERSION = '1.59';
-
-use base 'Exporter';
-
 our @EXPORT = qw/builtin_facet/;
 
-use Log::Report        'xml-compile', syntax => 'SHORT';
+use Log::Report        'xml-compile';
+
 use Math::BigInt;
 use Math::BigFloat;
 use XML::LibXML;  # for ::RegExp
