@@ -1,16 +1,20 @@
-# Copyrights 2006-2017 by [Mark Overmeer].
+# Copyrights 2006-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
-use warnings;
-use strict;
-no warnings 'recursion';  # trees can be quite deep
+# This code is part of distribution XML-Compile.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package XML::Compile::Translate;
 use vars '$VERSION';
-$VERSION = '1.59';
+$VERSION = '1.60';
 
 
+use warnings;
+use strict;
+no warnings 'recursion';  # trees can be quite deep
+
 # Errors are either in _class 'usage': called with request
 #                         or 'schema': syntax error in schema
 
@@ -431,6 +435,13 @@ sub simpleRestriction($$)
                    , where => $where, _class => 'schema';
 
         $base = $self->simpleType($tree->descend($simple, 'st'));
+
+        if((my $r) = $simple->getChildrenByLocalName('restriction')) {
+            # <simpleType><restriction><simpleType><restriction base=xxx></simpleType>@facets</simpleType>
+            my $basename = $r->getAttribute('base');
+            $typename = $self->rel2abs($where, $r, $basename) if $r;
+        }
+
         $tree->nextChild;
     }
 
