@@ -1,10 +1,14 @@
-# Copyrights 2006-2017 by [Mark Overmeer].
+# Copyrights 2006-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution XML-Compile.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
+
 package XML::Compile::Translate::Reader;
 use vars '$VERSION';
-$VERSION = '1.59';
+$VERSION = '1.60';
 
 use base 'XML::Compile::Translate';
 
@@ -12,9 +16,10 @@ use strict;
 use warnings;
 no warnings 'once', 'recursion';
 
-use Log::Report 'xml-compile', syntax => 'SHORT';
-use List::Util   qw/first/;
-use Scalar::Util qw/weaken blessed/;
+use Log::Report       'xml-compile';
+
+use List::Util         qw/first/;
+use Scalar::Util       qw/weaken blessed/;
 
 use XML::Compile::Util qw/pack_type odd_elements type_of_node SCHEMA2001i/;
 use XML::Compile::Iterator ();
