@@ -1,11 +1,14 @@
-# Copyrights 2006-2017 by [Mark Overmeer].
+# Copyrights 2006-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution XML-Compile.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
 
 package XML::Compile::Translate::Template;
 use vars '$VERSION';
-$VERSION = '1.59';
+$VERSION = '1.60';
 
 use base 'XML::Compile::Translate';
 
@@ -13,10 +16,11 @@ use strict;
 use warnings;
 no warnings 'once', 'recursion';
 
+use Log::Report    'xml-compile';
+
 use XML::Compile::Util
-  qw/odd_elements even_elements SCHEMA2001i pack_type unpack_type/;
-use Log::Report 'xml-compile', syntax => 'SHORT';
-use List::Util  qw/max first/;
+    qw/odd_elements even_elements SCHEMA2001i pack_type unpack_type/;
+use List::Util     qw/max first/;
 
 use vars '$VERSION';         # OODoc adds $VERSION to the script
 $VERSION ||= 'undef';
