@@ -1,11 +1,14 @@
-# Copyrights 2006-2017 by [Mark Overmeer].
+# Copyrights 2006-2018 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
+# This code is part of distribution XML-Compile.  Meta-POD processed with
+# OODoc into POD and HTML manual-pages.  See README.md
+# Copyright Mark Overmeer.  Licensed under the same terms as Perl itself.
  
 package XML::Compile::Translate::Writer;
 use vars '$VERSION';
-$VERSION = '1.59';
+$VERSION = '1.60';
 
 use base 'XML::Compile::Translate';
 
@@ -13,14 +16,15 @@ use strict;
 use warnings;
 no warnings 'once', 'recursion';
 
-use Log::Report   qw/xml-compile/;
+use Log::Report   'xml-compile';
+
 use List::Util    qw/first/;
 use Scalar::Util  qw/blessed weaken/;
-use XML::Compile::Util qw/pack_type unpack_type type_of_node SCHEMA2001i
-  SCHEMA2001 odd_elements even_elements/;
+use Encode        qw/encode/;
 
 use XML::LibXML;
-use Encode        qw/encode/;
+use XML::Compile::Util qw/pack_type unpack_type type_of_node SCHEMA2001i
+    SCHEMA2001 odd_elements even_elements/;
 
 
 # Each action implementation returns a code reference, which will be
